@@ -8,23 +8,21 @@ from dagstermill.io_managers import local_output_notebook_io_manager
 from dagster import (
     Field,
     FileHandle,
-    InputDefinition,
+    In,
     Int,
     List,
-    ModeDefinition,
-    OutputDefinition,
+    Out,
     ResourceDefinition,
     String,
-    composite_solid,
     fs_io_manager,
     job,
-    pipeline,
     repository,
     resource,
-    solid,
 )
-from dagster.core.storage.file_manager import local_file_manager
-from dagster.utils import PICKLE_PROTOCOL, file_relative_path
+from dagster._core.definitions.utils import DEFAULT_OUTPUT
+from dagster._core.storage.file_manager import local_file_manager
+from dagster._legacy import InputDefinition, ModeDefinition, composite_solid, pipeline, solid
+from dagster._utils import PICKLE_PROTOCOL, file_relative_path
 
 try:
     from dagster_pandas import DataFrame
@@ -60,26 +58,15 @@ def nb_test_path(name):
     return file_relative_path(__file__, f"notebooks/{name}.ipynb")
 
 
-def test_nb_solid(name, **kwargs):
-    output_defs = kwargs.pop("output_defs", [OutputDefinition(is_required=False)])
-
-    return dagstermill.define_dagstermill_solid(
-        name=name,
-        notebook_path=nb_test_path(name),
-        output_notebook_name="notebook",
-        output_defs=output_defs,
-        **kwargs,
-    )
-
-
-def test_nb_op(name, path, **kwargs):
-    output_defs = kwargs.pop("output_defs", [OutputDefinition(is_required=False)])
+def test_nb_op(name, **kwargs):
+    outs = kwargs.pop("outs", {DEFAULT_OUTPUT: Out(is_required=False)})
+    path = kwargs.pop("path", nb_test_path(name))
 
     return dagstermill.define_dagstermill_op(
         name=name,
         notebook_path=path,
         output_notebook_name="notebook",
-        output_defs=output_defs,
+        outs=outs,
         **kwargs,
     )
 
@@ -94,7 +81,7 @@ default_mode_defs = [
 ]
 
 
-hello_world = test_nb_solid("hello_world", output_defs=[])
+hello_world = test_nb_op("hello_world", outs={})
 
 
 @pipeline(mode_defs=default_mode_defs)
@@ -104,8 +91,8 @@ def hello_world_pipeline():
 
 hello_world_op = test_nb_op(
     "hello_world_op",
-    nb_test_path("hello_world"),
-    output_defs=[],
+    path=nb_test_path("hello_world"),
+    outs={},
 )
 
 
@@ -121,7 +108,7 @@ def build_hello_world_job():
     return hello_world_job
 
 
-hello_world_with_custom_tags_and_description = dagstermill.define_dagstermill_solid(
+hello_world_with_custom_tags_and_description = dagstermill.factory.define_dagstermill_solid(
     name="hello_world_custom",
     notebook_path=nb_test_path("hello_world"),
     output_notebook_name="notebook",
@@ -135,13 +122,13 @@ def hello_world_with_custom_tags_and_description_pipeline():
     hello_world_with_custom_tags_and_description()
 
 
-hello_world_config = test_nb_solid(
+hello_world_config = test_nb_op(
     "hello_world_config",
     config_schema={"greeting": Field(String, is_required=False, default_value="hello")},
 )
 
 
-goodbye_config = dagstermill.define_dagstermill_solid(
+goodbye_config = dagstermill.factory.define_dagstermill_solid(
     name="goodbye_config",
     notebook_path=nb_test_path("print_dagstermill_context_solid_config"),
     output_notebook_name="notebook",
@@ -172,7 +159,7 @@ def hello_world_with_output_notebook_pipeline():
     load_notebook(notebook)
 
 
-hello_world_no_output_notebook_no_file_manager = dagstermill.define_dagstermill_solid(
+hello_world_no_output_notebook_no_file_manager = dagstermill.factory.define_dagstermill_solid(
     name="hello_world_no_output_notebook_no_file_manager",
     notebook_path=nb_test_path("hello_world"),
 )
@@ -183,7 +170,7 @@ def hello_world_no_output_notebook_no_file_manager_pipeline():
     hello_world_no_output_notebook_no_file_manager()
 
 
-hello_world_no_output_notebook = dagstermill.define_dagstermill_solid(
+hello_world_no_output_notebook = dagstermill.factory.define_dagstermill_solid(
     name="hello_world_no_output_notebook",
     notebook_path=nb_test_path("hello_world"),
 )
@@ -194,7 +181,7 @@ def hello_world_no_output_notebook_pipeline():
     hello_world_no_output_notebook()
 
 
-hello_world_output = test_nb_solid("hello_world_output", output_defs=[OutputDefinition(str)])
+hello_world_output = test_nb_op("hello_world_output", outs={DEFAULT_OUTPUT: Out(str)})
 
 
 @pipeline(mode_defs=default_mode_defs)
@@ -202,8 +189,8 @@ def hello_world_output_pipeline():
     hello_world_output()
 
 
-hello_world_explicit_yield = test_nb_solid(
-    "hello_world_explicit_yield", output_defs=[OutputDefinition(str)]
+hello_world_explicit_yield = test_nb_op(
+    "hello_world_explicit_yield", outs={DEFAULT_OUTPUT: Out(str)}
 )
 
 
@@ -212,7 +199,7 @@ def hello_world_explicit_yield_pipeline():
     hello_world_explicit_yield()
 
 
-hello_logging = test_nb_solid("hello_logging")
+hello_logging = test_nb_op("hello_logging")
 
 
 @pipeline(mode_defs=default_mode_defs)
@@ -220,23 +207,15 @@ def hello_logging_pipeline():
     hello_logging()
 
 
-add_two_numbers = test_nb_solid(
+add_two_numbers = test_nb_op(
     "add_two_numbers",
-    input_defs=[
-        InputDefinition(name="a", dagster_type=Int),
-        InputDefinition(name="b", dagster_type=Int),
-    ],
-    output_defs=[OutputDefinition(Int)],
+    ins={"a": In(int), "b": In(int)},
+    outs={DEFAULT_OUTPUT: Out(int)},
 )
 
 
-mult_two_numbers = test_nb_solid(
-    "mult_two_numbers",
-    input_defs=[
-        InputDefinition(name="a", dagster_type=Int),
-        InputDefinition(name="b", dagster_type=Int),
-    ],
-    output_defs=[OutputDefinition(Int)],
+mult_two_numbers = test_nb_op(
+    "mult_two_numbers", ins={"a": In(int), "b": In(int)}, outs={DEFAULT_OUTPUT: Out(int)}
 )
 
 
@@ -280,11 +259,11 @@ def load_constant(context):
 def notebook_dag_pipeline():
     a = load_constant.alias("load_a")()
     b = load_constant.alias("load_b")()
-    c, _ = add_two_numbers(a, b)
-    mult_two_numbers(c, b)
+    num, _ = add_two_numbers(a, b)
+    mult_two_numbers(num, b)
 
 
-error_notebook = test_nb_solid("error_notebook")
+error_notebook = test_nb_op("error_notebook")
 
 
 @pipeline(mode_defs=default_mode_defs)
@@ -294,25 +273,19 @@ def error_pipeline():
 
 if DAGSTER_PANDAS_PRESENT and SKLEARN_PRESENT and MATPLOTLIB_PRESENT:
 
-    clean_data = test_nb_solid("clean_data", output_defs=[OutputDefinition(DataFrame)])
+    clean_data = test_nb_op("clean_data", outs={DEFAULT_OUTPUT: Out(DataFrame)})
 
     # FIXME add an output to this
-    tutorial_LR = test_nb_solid(
-        "tutorial_LR",
-        input_defs=[InputDefinition(name="df", dagster_type=DataFrame)],
-    )
+    tutorial_LR = test_nb_op("tutorial_LR", ins={"df": In(DataFrame)})
 
-    tutorial_RF = test_nb_solid(
-        "tutorial_RF",
-        input_defs=[InputDefinition(name="df", dagster_type=DataFrame)],
-    )
+    tutorial_RF = test_nb_op("tutorial_RF", ins={"df": In(DataFrame)})
 
     @pipeline(mode_defs=default_mode_defs)
     def tutorial_pipeline():
-        df, _ = clean_data()
+        dfr, _ = clean_data()
         # FIXME get better names for these
-        tutorial_LR(df)
-        tutorial_RF(df)
+        tutorial_LR(dfr)
+        tutorial_RF(dfr)
 
 
 @solid("resource_solid", required_resource_keys={"list"})
@@ -321,15 +294,15 @@ def resource_solid(context):
     return True
 
 
-hello_world_resource = test_nb_solid(
+hello_world_resource = test_nb_op(
     "hello_world_resource",
-    input_defs=[InputDefinition("nonce")],
+    ins={"nonce": In()},
     required_resource_keys={"list"},
 )
 
-hello_world_resource_with_exception = test_nb_solid(
+hello_world_resource_with_exception = test_nb_op(
     "hello_world_resource_with_exception",
-    input_defs=[InputDefinition("nonce")],
+    ins={"nonce": In()},
     required_resource_keys={"list"},
 )
 
@@ -417,7 +390,7 @@ def resource_with_exception_pipeline():
     hello_world_resource_with_exception(resource_solid())
 
 
-bad_kernel = test_nb_solid("bad_kernel")
+bad_kernel = test_nb_op("bad_kernel")
 
 
 @pipeline(mode_defs=default_mode_defs)
@@ -425,9 +398,7 @@ def bad_kernel_pipeline():
     bad_kernel()
 
 
-reimport = test_nb_solid(
-    "reimport", input_defs=[InputDefinition("l", List[int])], output_defs=[OutputDefinition(int)]
-)
+reimport = test_nb_op("reimport", ins={"l": In(List[int])}, outs={DEFAULT_OUTPUT: Out(int)})
 
 
 @solid
@@ -440,7 +411,7 @@ def reimport_pipeline():
     reimport(lister())
 
 
-yield_3 = test_nb_solid("yield_3", output_defs=[OutputDefinition(Int)])
+yield_3 = test_nb_op("yield_3", outs={DEFAULT_OUTPUT: Out(int)})
 
 
 @pipeline(mode_defs=default_mode_defs)
@@ -448,7 +419,7 @@ def yield_3_pipeline():
     yield_3()
 
 
-yield_obj = test_nb_solid("yield_obj")
+yield_obj = test_nb_op("yield_obj")
 
 
 @pipeline(mode_defs=default_mode_defs)
@@ -458,20 +429,18 @@ def yield_obj_pipeline():
 
 @pipeline(mode_defs=default_mode_defs)
 def retries_pipeline():
-    test_nb_solid("raise_retry")()
-    test_nb_solid("yield_retry")()
+    test_nb_op("raise_retry")()
+    test_nb_op("yield_retry")()
 
 
 @pipeline(mode_defs=default_mode_defs)
 def failure_pipeline():
-    test_nb_solid("raise_failure")()
-    test_nb_solid("yield_failure")()
+    test_nb_op("raise_failure")()
+    test_nb_op("yield_failure")()
 
 
-yield_something = test_nb_solid(
-    "yield_something",
-    input_defs=[InputDefinition("obj", str)],
-    output_defs=[OutputDefinition(str, "result")],
+yield_something = test_nb_op(
+    "yield_something", ins={"obj": In(str)}, outs={DEFAULT_OUTPUT: Out(str)}
 )
 
 
@@ -491,9 +460,9 @@ def fan_in(a, b):
     ]
 )
 def fan_in_notebook_pipeline():
-    a, _ = yield_something.alias("solid_1")()
-    b, _ = yield_something.alias("solid_2")()
-    fan_in(a, b)
+    val_a, _ = yield_something.alias("solid_1")()
+    val_b, _ = yield_something.alias("solid_2")()
+    fan_in(val_a, val_b)
 
 
 @pipeline(
@@ -506,9 +475,9 @@ def fan_in_notebook_pipeline():
     ]
 )
 def fan_in_notebook_pipeline_in_mem():
-    a, _ = yield_something.alias("solid_1")()
-    b, _ = yield_something.alias("solid_2")()
-    fan_in(a, b)
+    val_a, _ = yield_something.alias("solid_1")()
+    val_b, _ = yield_something.alias("solid_2")()
+    fan_in(val_a, val_b)
 
 
 @composite_solid
@@ -534,7 +503,7 @@ def composite_pipeline():
 # Back compat
 ###################################################################################################
 
-hello_world_legacy = dagstermill.define_dagstermill_solid(
+hello_world_legacy = dagstermill.factory.define_dagstermill_solid(
     name="hello_world_legacy",
     notebook_path=nb_test_path("hello_world"),
     output_notebook="notebook",
