@@ -2,14 +2,14 @@ import os
 from pathlib import Path
 from typing import Any, List, Optional
 
-from dagster import check
-from dagster.config.field import Field
-from dagster.core.definitions.events import AssetKey
-from dagster.core.definitions.metadata import MetadataEntry, MetadataValue
-from dagster.core.execution.context.input import InputContext
-from dagster.core.execution.context.output import OutputContext
-from dagster.core.storage.io_manager import IOManager, io_manager
-from dagster.utils import mkdir_p
+import dagster._check as check
+from dagster._config import Field
+from dagster._core.definitions.events import AssetKey
+from dagster._core.definitions.metadata import MetadataEntry, MetadataValue
+from dagster._core.execution.context.input import InputContext
+from dagster._core.execution.context.output import OutputContext
+from dagster._core.storage.io_manager import IOManager, io_manager
+from dagster._utils import mkdir_p
 
 
 class OutputNotebookIOManager(IOManager):
